
<!---
FrozenIsBool True
-->

##Example

A getter can get something from a dict like instance where there is a #get or #map@get key.
And also a #get:<KeyStr> would do the same job as getting with the GetKeyStr <KeyStr>
...it will be useful for latter